# pycvtools

[![forthebadge made-with-python](http://ForTheBadge.com/images/badges/made-with-python.svg)](https://www.python.org/)                 
[![Python 3.10](https://img.shields.io/badge/python-3.10-blue.svg)](https://www.python.org/downloads/)   

## Functionality of the pydlmodels

- EDIT THE DOCUMENT
> - Name 
> - Email
> - Country / Address
> - Mask Mobile and Passport number


```
pip install pydataedit
```
##### To run
```
from pydataedit import *
```


